==> matwm2-0.0.62.tar.gz: matwm2-0.0.62/defaults.h <==
#define DEF_CFG "\
background            darkred\n\
inactive_background   dimgray\n\
foreground            lightgray\n\
inactive_foreground   darkgray\n\
font                  fixed\n\
button1               move\n\
button2               none\n\
button3               resize\n\
button4               raise\n\
button5               lower\n\
border_width          4\n\
snap                  5\n\
desktops              4\n\
ignore_modifier       mod2 lock\n\
mouse_modifier        mod1\n\
key                   mod1 Tab                next\n\
key                   mod1 shift Tab          prev\n\
key                   control mod1 s          iconify\n\
key                   control mod1 x          maximise\n\
key                   control mod1 f          fullscreen\n\
key                   control mod1 e          expand\n\
key                   control mod1 q          close\n\
key                   control mod1 d          sticky\n\
key                   control mod1 t          title\n\
key                   control mod1 y          topleft\n\
key                   control mod1 u          topright\n\
key                   control mod1 b          bottomleft\n\
key                   control mod1 n          bottomright\n\
key                   control mod1 o          ontop\n\
key                   control mod1 p          below\n\
key                   control mod1 a          iconify_all\n\
key                   control mod1 Right      next_desktop\n\
key                   control mod1 Left       prev_desktop\n\
key                   control mod1 Return     exec xterm\n\
key                   mod4 s                  iconify\n\
key                   mod4 x                  maximise\n\
key                   mod4 f                  fullscreen\n\
key                   mod4 e                  expand\n\
key                   mod4 q                  close\n\
key                   mod4 d                  sticky\n\
key                   mod4 t                  title\n\
key                   mod4 y                  topleft\n\
key                   mod4 u                  topright\n\
key                   mod4 b                  bottomleft\n\
key                   mod4 n                  bottomright\n\
key                   mod4 o                  ontop\n\
key                   mod4 p                  below\n\
key                   mod4 a                  iconify_all\n\
key                   mod4 Right              next_desktop\n\
key                   mod4 Left               prev_desktop\n"

#define MINSIZE                 5
#define CFGFN                   ".matwmrc"
#define NO_TITLE                "-"

==> matwm2-0.0.65.tar.gz: matwm2-0.0.65/defaults.h <==
#define DEF_CFG "\
background            darkred\n\
inactive_background   dimgray\n\
foreground            lightgray\n\
inactive_foreground   darkgray\n\
font                  fixed\n\
button1               move\n\
button2               none\n\
button3               resize\n\
button4               raise\n\
button5               lower\n\
border_width          4\n\
snap                  5\n\
desktops              4\n\
ignore_modifier       mod2 lock\n\
mouse_modifier        mod1\n\
key                   mod1 Tab                next\n\
key                   mod1 shift Tab          prev\n\
key                   control mod1 s          iconify\n\
key                   control mod1 x          maximise\n\
key                   control mod1 h          maximise h\n\
key                   control mod1 v          maximise v\n\
key                   control mod1 f          fullscreen\n\
key                   control mod1 e          expand\n\
key                   control mod1 z          expand h\n\
key                   control mod1 j          expand v\n\
key                   control mod1 q          close\n\
key                   control mod1 d          sticky\n\
key                   control mod1 t          title\n\
key                   control mod1 y          to_border tl\n\
key                   control mod1 u          to_border tr\n\
key                   control mod1 b          to_border bl\n\
key                   control mod1 n          to_border br\n\
key                   control mod1 o          ontop\n\
key                   control mod1 p          below\n\
key                   control mod1 a          iconify_all\n\
key                   control mod1 Right      next_desktop\n\
key                   control mod1 Left       prev_desktop\n\
key                   control mod1 Return     exec xterm\n\
key                   mod4 s                  iconify\n\
key                   mod4 x                  maximise\n\
key                   mod4 h                  maximise h\n\
key                   mod4 v                  maximise v\n\
key                   mod4 f                  fullscreen\n\
key                   mod4 e                  expand\n\
key                   mod4 z                  expand h\n\
key                   mod4 j                  expand v\n\
key                   mod4 q                  close\n\
key                   mod4 d                  sticky\n\
key                   mod4 t                  title\n\
key                   mod4 y                  to_border tl\n\
key                   mod4 u                  to_border tr\n\
key                   mod4 b                  to_border bl\n\
key                   mod4 n                  to_border br\n\
key                   mod4 o                  ontop\n\
key                   mod4 p                  below\n\
key                   mod4 a                  iconify_all\n\
key                   mod4 Right              next_desktop\n\
key                   mod4 Left               prev_desktop\n"

#define MINSIZE                 5
#define CFGFN                   ".matwmrc"
#define GCFGFN									"/etc/matwmrc"
#define NO_TITLE                "-"
